@@ -35,12 +35,12 @@ class OpenSearchUtils:
         res = self.client.search(index=index, body=body)
         return self.get_df_from_es(res)
 
-    def search_by_condition(self, index, must=[], should=[], must_not=[], size=10000, fields=['*']):
+    def search_by_condition(self, index, must=[], should=[], must_not=[], size=10000, fields=['*'], sort=''):
         logging.debug("search by query, index: %s, must: %s, should: %s, must_not: %s", index, must, should, must_not)
         if fields is None or len(fields) > 0:
-            res = self.client.search(index=index, body={"size": size, "_source": fields,"query":{"bool":{"must":must,"should":should,"must_not":must_not}}})
+            res = self.client.search(index=index, body={"size": size, "_source": fields,"query":{"bool":{"must":must,"should":should,"must_not":must_not}}}, sort=sort, request_timeout=30)
         else:
-            res = self.client.search(index=index, body={"size": size, "query":{"bool":{"must":must,"should":should,"must_not":must_not}}})
+            res = self.client.search(index=index, body={"size": size, "query":{"bool":{"must":must,"should":should,"must_not":must_not}}}, sort=sort, request_timeout=30)
         return self.get_df_from_es(res)
 
 def get_client():
